@@ -5,7 +5,6 @@ from functools import lru_cache
 from typing import Callable, Iterable, List, Optional
 
 import click
-import uvloop
 from aiohttp import web
 from aiohttp.web import Application
 
@@ -13,7 +12,6 @@ from .logger import logger, setup_logging
 from .spec import OpenApiSpec
 from .utils import get_debug_flag
 
-asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
 HOST = os.environ.get("MICRO_SERVICE_HOST", "0.0.0.0")
 PORT = os.environ.get("MICRO_SERVICE_PORT", 8080)
 
@@ -25,8 +23,8 @@ class OpenApiClient(click.Group):
         setup_app: Optional[Callable[[Application], None]] = None,
         base_path: str = "",
         commands: Optional[List] = None,
-        serve_spec: bool = True,
         index: int = -1,
+        loop: Optional[asyncio.AbstractEventLoop] = None,
         **extra,
     ) -> None:
         params = list(extra.pop("params", None) or ())
@@ -35,6 +33,7 @@ class OpenApiClient(click.Group):
         self.setup_app = setup_app
         self.base_path: str = base_path or ""
         self.index = index
+        self.loop = loop
         params.extend(
             (
                 click.Option(
@@ -114,6 +113,10 @@ class OpenApiClient(click.Group):
         ctx.exit()
 
 
+def open_api_cli(ctx: click.Context) -> OpenApiClient:
+    return ctx.obj["cli"]
+
+
 @click.command("serve", short_help="Start aiohttp server.")
 @click.option(
     "--host", "-h", default=HOST, help=f"The interface to bind to (default to {HOST})"
@@ -136,8 +139,15 @@ class OpenApiClient(click.Group):
 @click.pass_context
 def serve(ctx, host, port, index, reload):
     """Run the aiohttp server."""
-    cli = ctx.obj["cli"]
+    cli = open_api_cli(ctx)
     cli.index = index
     app = cli.get_serve_app()
     access_log = logger if ctx.obj["log_level"] else None
-    web.run_app(app, host=host, port=port, access_log=access_log)
+    web.run_app(
+        app,
+        host=host,
+        port=port,
+        access_log=access_log,
+        loop=cli.loop,
+        print=access_log.info if access_log else None,
+    )
